var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { cleanup } from '@testing-library/react';
import { renderHook, act } from '@testing-library/react-hooks';
import { defaultHttpReqConfig, HttpContext, HttpContextToken, HttpMethod, RequestErroredEvent, RequestStartedEvent, RequestSuccededEvent, useHttpEvent, useHttpRequest, } from '..';
import { HttpClientProviderConfigFixture } from './fixtures/http-client-config-provider.fixture';
var fetch = global.fetch;
describe('use-http-event', function () {
    var fetchResponse = {
        name: 'Phelony',
        role: 'Admin',
    };
    beforeEach(function () {
        jest.useFakeTimers();
        jest.spyOn(global, 'setTimeout');
    });
    afterEach(function () {
        cleanup();
        fetch.resetMocks();
        jest.runAllTimers();
    });
    it('should run the registered handler when a request starts', function (done) {
        fetch.mockResponseOnce(JSON.stringify(fetchResponse));
        var showGlobalLoader = new HttpContextToken(true);
        var reqContext = new HttpContext().set(showGlobalLoader, false);
        renderHook(function () {
            return useHttpEvent(RequestStartedEvent, function (request) {
                try {
                    expect(request.url).toBe('https://phelony.com/comments');
                    expect(request.baseUrl).toBe('https://phelony.com');
                    expect(request.relativeUrl).toBe('comments');
                    expect(request.body).toBeUndefined();
                    expect(request.headers).toEqual(defaultHttpReqConfig.reqOptions.headers);
                    expect(request.context).toBe(reqContext);
                    expect(request.getContextValue(showGlobalLoader)).toBe(false);
                    expect(request.credentials).toBeUndefined();
                    expect(request.maxAge).toBe(0);
                    expect(request.method).toBe(HttpMethod.Get);
                    expect(request.queryParams).toBeUndefined();
                    expect(request.serializedQueryParams).toBe('');
                    expect(request.signal).toBeInstanceOf(AbortSignal);
                    expect(request.urlWithParams).toBe('https://phelony.com/comments');
                    done();
                }
                catch (expectError) {
                    done(expectError);
                }
            });
        }, {
            wrapper: HttpClientProviderConfigFixture.create(),
        });
        var result = renderHook(function () {
            return useHttpRequest({
                baseUrlOverride: 'https://phelony.com',
                relativeUrl: 'comments',
                context: reqContext,
            });
        }, {
            wrapper: HttpClientProviderConfigFixture.create(),
        }).result;
        var _a = result.current, performRequest = _a[1];
        (function () { return __awaiter(void 0, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, act(function () { return __awaiter(void 0, void 0, void 0, function () {
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0: return [4 /*yield*/, performRequest()];
                                    case 1:
                                        _a.sent();
                                        return [2 /*return*/];
                                }
                            });
                        }); })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); })();
    });
    it('should run the registered handler when a request goes in error', function (done) {
        var fetchError = new Error('Fetch error');
        fetch.mockRejectOnce(fetchError);
        var showGlobalLoader = new HttpContextToken(true);
        var reqContext = new HttpContext().set(showGlobalLoader, false);
        renderHook(function () {
            return useHttpEvent(RequestErroredEvent, function (error) {
                var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p;
                try {
                    expect(error.status).toBeUndefined();
                    expect(error.statusText).toBeUndefined();
                    expect(error.response).toBeUndefined();
                    expect(error.nativeError).toBe(fetchError);
                    expect((_a = error.request) === null || _a === void 0 ? void 0 : _a.url).toBe('https://phelony.com/comments');
                    expect((_b = error.request) === null || _b === void 0 ? void 0 : _b.baseUrl).toBe('https://phelony.com');
                    expect((_c = error.request) === null || _c === void 0 ? void 0 : _c.relativeUrl).toBe('comments');
                    expect((_d = error.request) === null || _d === void 0 ? void 0 : _d.body).toBeUndefined();
                    expect((_e = error.request) === null || _e === void 0 ? void 0 : _e.headers).toEqual(defaultHttpReqConfig.reqOptions.headers);
                    expect((_f = error.request) === null || _f === void 0 ? void 0 : _f.context).toBe(reqContext);
                    expect((_g = error.request) === null || _g === void 0 ? void 0 : _g.getContextValue(showGlobalLoader)).toBe(false);
                    expect((_h = error.request) === null || _h === void 0 ? void 0 : _h.credentials).toBeUndefined();
                    expect((_j = error.request) === null || _j === void 0 ? void 0 : _j.maxAge).toBe(0);
                    expect((_k = error.request) === null || _k === void 0 ? void 0 : _k.method).toBe(HttpMethod.Get);
                    expect((_l = error.request) === null || _l === void 0 ? void 0 : _l.queryParams).toBeUndefined();
                    expect((_m = error.request) === null || _m === void 0 ? void 0 : _m.serializedQueryParams).toBe('');
                    expect((_o = error.request) === null || _o === void 0 ? void 0 : _o.signal).toBeInstanceOf(AbortSignal);
                    expect((_p = error.request) === null || _p === void 0 ? void 0 : _p.urlWithParams).toBe('https://phelony.com/comments');
                    done();
                }
                catch (expectError) {
                    done(expectError);
                }
            });
        }, {
            wrapper: HttpClientProviderConfigFixture.create(),
        });
        var result = renderHook(function () {
            return useHttpRequest({
                baseUrlOverride: 'https://phelony.com',
                relativeUrl: 'comments',
                context: reqContext,
            });
        }, {
            wrapper: HttpClientProviderConfigFixture.create(),
        }).result;
        var _a = result.current, performRequest = _a[1];
        (function () { return __awaiter(void 0, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, act(function () { return __awaiter(void 0, void 0, void 0, function () {
                            var error_1;
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0:
                                        _a.trys.push([0, 2, , 3]);
                                        return [4 /*yield*/, performRequest()];
                                    case 1:
                                        _a.sent();
                                        return [3 /*break*/, 3];
                                    case 2:
                                        error_1 = _a.sent();
                                        return [3 /*break*/, 3];
                                    case 3: return [2 /*return*/];
                                }
                            });
                        }); })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); })();
    });
    it('should run the registered handler when a request completes', function (done) {
        fetch.mockResponseOnce(JSON.stringify(fetchResponse));
        var showGlobalLoader = new HttpContextToken(true);
        var reqContext = new HttpContext().set(showGlobalLoader, false);
        renderHook(function () {
            return useHttpEvent(RequestSuccededEvent, function (_a) {
                var request = _a.request, response = _a.response;
                try {
                    expect(request.url).toBe('https://phelony.com/comments');
                    expect(request.baseUrl).toBe('https://phelony.com');
                    expect(request.relativeUrl).toBe('comments');
                    expect(request.body).toBeUndefined();
                    expect(request.headers).toEqual(defaultHttpReqConfig.reqOptions.headers);
                    expect(request.context).toBe(reqContext);
                    expect(request.getContextValue(showGlobalLoader)).toBe(false);
                    expect(request.credentials).toBeUndefined();
                    expect(request.maxAge).toBe(0);
                    expect(request.method).toBe(HttpMethod.Get);
                    expect(request.queryParams).toBeUndefined();
                    expect(request.serializedQueryParams).toBe('');
                    expect(request.signal).toBeInstanceOf(AbortSignal);
                    expect(request.urlWithParams).toBe('https://phelony.com/comments');
                    expect(response).toEqual(fetchResponse);
                    done();
                }
                catch (expectError) {
                    done(expectError);
                }
            });
        }, {
            wrapper: HttpClientProviderConfigFixture.create(),
        });
        var result = renderHook(function () {
            return useHttpRequest({
                baseUrlOverride: 'https://phelony.com',
                relativeUrl: 'comments',
                context: reqContext,
            });
        }, {
            wrapper: HttpClientProviderConfigFixture.create(),
        }).result;
        var _a = result.current, performRequest = _a[1];
        (function () { return __awaiter(void 0, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, act(function () { return __awaiter(void 0, void 0, void 0, function () {
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0: return [4 /*yield*/, performRequest()];
                                    case 1:
                                        _a.sent();
                                        return [2 /*return*/];
                                }
                            });
                        }); })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); })();
    });
});
